@@ -1,20 +1,25 @@
 import tensorflow as tf
 
-from tensorflow_similarity.training_metrics import DistanceMetric
-from tensorflow_similarity.training_metrics import DistanceGapMetric
 from tensorflow_similarity.distances import CosineDistance
+from tensorflow_similarity.training_metrics import DistanceGapMetric, DistanceMetric
 from tensorflow_similarity.types import FloatTensor
 
-EMB1 = tf.nn.l2_normalize([
-    [0.5, 1, 0.5],
-    [0.2, 0.8, 0.4],
-], axis=-1)
-EMB2 = tf.nn.l2_normalize([
-    [0.66, 0.5, 0.34],
-    [0.77, 0.9, 0.92],
-], axis=-1)
+EMB1 = tf.nn.l2_normalize(
+    [
+        [0.5, 1, 0.5],
+        [0.2, 0.8, 0.4],
+    ],
+    axis=-1,
+)
+EMB2 = tf.nn.l2_normalize(
+    [
+        [0.66, 0.5, 0.34],
+        [0.77, 0.9, 0.92],
+    ],
+    axis=-1,
+)
 
-LABELS = tf.Variable([[1], [1], [2], [2]], dtype='int32')
+LABELS = tf.Variable([[1], [1], [2], [2]], dtype="int32")
 EMBEDDINGS = tf.Variable(tf.concat((EMB1, EMB2), axis=0))
 
 
@@ -25,7 +30,7 @@ def cosine(a: FloatTensor, b: FloatTensor) -> FloatTensor:
 
 
 def compute_metric(distance, aggregate, labels, embeddings):
-    'Inner function that call the core class'
+    "Inner function that call the core class"
     metric = DistanceMetric(distance, aggregate=aggregate)
     metric.update_state(labels, embeddings, None)
     return metric.result()
@@ -38,7 +43,7 @@ def manual_hard_mining(mydistance, E1, E2):
 
 
 def test_distance_metric_serialize():
-    metric = DistanceMetric('cosine', aggregate='max')
+    metric = DistanceMetric("cosine", aggregate="max")
     config = metric.get_config()
     metric2 = DistanceMetric.from_config(config)
     assert isinstance(metric2.distance, CosineDistance)
@@ -50,13 +55,12 @@ def test_distance_metric_serialize():
 
 
 class DistanceMetricsTest(tf.test.TestCase):
-
     def test_avg_positive(self):
 
-        agg = ['avg', tf.reduce_mean]
+        agg = ["avg", tf.reduce_mean]
 
         # metric computation
-        metric_val = compute_metric('cosine', agg[0], LABELS, EMBEDDINGS)
+        metric_val = compute_metric("cosine", agg[0], LABELS, EMBEDDINGS)
 
         # manual computation
         hard_distances = manual_hard_mining(cosine, EMB1, EMB2)
@@ -64,10 +68,10 @@ class DistanceMetricsTest(tf.test.TestCase):
         self.assertAllClose(metric_val, manual_val)
 
     def test_sum_positive(self):
-        agg = ['sum', tf.reduce_sum]
+        agg = ["sum", tf.reduce_sum]
 
         # metric computation
-        metric_val = compute_metric('cosine', agg[0], LABELS, EMBEDDINGS)
+        metric_val = compute_metric("cosine", agg[0], LABELS, EMBEDDINGS)
 
         # manual computation
         hard_distances = manual_hard_mining(cosine, EMB1, EMB2)
@@ -75,10 +79,10 @@ class DistanceMetricsTest(tf.test.TestCase):
         self.assertAllClose(metric_val, manual_val)
 
     def test_max_positive(self):
-        agg = ['max', tf.reduce_max]
+        agg = ["max", tf.reduce_max]
 
         # metric computation
-        metric_val = compute_metric('cosine', agg[0], LABELS, EMBEDDINGS)
+        metric_val = compute_metric("cosine", agg[0], LABELS, EMBEDDINGS)
 
         # manual computation
         hard_distances = manual_hard_mining(cosine, EMB1, EMB2)
@@ -86,10 +90,10 @@ class DistanceMetricsTest(tf.test.TestCase):
         self.assertAllClose(metric_val, manual_val)
 
     def test_min_positive(self):
-        agg = ['min', tf.reduce_min]
+        agg = ["min", tf.reduce_min]
 
         # metric computation
-        metric_val = compute_metric('cosine', agg[0], LABELS, EMBEDDINGS)
+        metric_val = compute_metric("cosine", agg[0], LABELS, EMBEDDINGS)
 
         # manual computation
         hard_distances = manual_hard_mining(cosine, EMB1, EMB2)
@@ -98,6 +102,6 @@ class DistanceMetricsTest(tf.test.TestCase):
 
 
 def test_gap():
-    metric = DistanceGapMetric('cosine')
+    metric = DistanceGapMetric("cosine")
     metric.update_state(LABELS, EMBEDDINGS, None)
     metric.result()
